==> bbctrl-2.0.0-rc2.tar.bz2: bbctrl-2.0.0/src/js/view-docs.js <==
/******************************************************************************\

                  This file is part of the Buildbotics firmware.

         Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.

          This Source describes Open Hardware and is licensed under the
                                  CERN-OHL-S v2.

          You may redistribute and modify this Source and make products
     using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).
            This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED
     WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS
      FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable
                                   conditions.

                 Source location: https://github.com/buildbotics

       As per CERN-OHL-S v2 section 4, should You produce hardware based on
     these sources, You must maintain the Source Location clearly visible on
     the external case of the CNC Controller or other product you make using
                                   this Source.

                 For more information, email info@buildbotics.com

\******************************************************************************/

'use strict'


module.exports = {
  template: '#view-docs-template',
  props: ['config', 'template', 'state'],


  data: function () {
    return {
      view: undefined
    }
  },


  components: {
    'docs-help':    {template: '#docs-help-template'},
    'docs-gcode': {
      template: '#docs-gcode-template',
      data: function () {return {showUnimplemented: false}}
    },
    'docs-license':   {template: '#docs-license-template'}
  },


  events: {
    route: function (path) {
      if (path[0] != 'docs') return;
      var view = path.length < 2 ? '' : path[1];

      if (typeof this.$options.components['docs-' + view] == 'undefined')
        this.$root.replace_route('docs:help');
      else this.view = view;
    },
  },


  ready: function () {this.$root.parse_hash()}
}

==> bbctrl-2.0.2.tar.bz2: bbctrl-2.0.2/src/js/view-docs.js <==
/******************************************************************************\

                  This file is part of the Buildbotics firmware.

         Copyright (c) 2015 - 2023, Buildbotics LLC, All rights reserved.

          This Source describes Open Hardware and is licensed under the
                                  CERN-OHL-S v2.

          You may redistribute and modify this Source and make products
     using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).
            This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED
     WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS
      FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable
                                   conditions.

                 Source location: https://github.com/buildbotics

       As per CERN-OHL-S v2 section 4, should You produce hardware based on
     these sources, You must maintain the Source Location clearly visible on
     the external case of the CNC Controller or other product you make using
                                   this Source.

                 For more information, email info@buildbotics.com

\******************************************************************************/



module.exports = {
  template: '#view-docs-template',
  props: ['config', 'template', 'state'],


  data() {
    return {
      view: undefined
    }
  },


  components: {
    'docs-help':    {template: '#docs-help-template'},
    'docs-gcode': {
      template: '#docs-gcode-template',
      data() {return {showUnimplemented: false}}
    },
    'docs-license':   {template: '#docs-license-template'}
  },


  events: {
    route(path) {
      if (path[0] != 'docs') return
      let view = path.length < 2 ? '' : path[1]

      if (typeof this.$options.components['docs-' + view] == 'undefined')
        this.$root.replace_route('docs:help')
      else this.view = view
    },
  },


  ready() {this.$root.parse_hash()}
}
